Package: netropy
Title: Statistical Entropy Analysis of Network Data
Version: 0.3.0
Authors@R: 
    person(given = "Termeh",
           family = "Shafie",
           role = c("aut", "cre"),
           email = "termeh.shafie@uni-konstanz.de")
Description: Statistical entropy analysis of network data as introduced by Frank and Shafie (2016) <doi:10.1177/0759106315615511>, and a in textbook which is in progress.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Imports: ggraph, ggplot2, igraph
RoxygenNote: 7.3.2
Language: en-US
Depends: R (>= 3.6)
Suggests: testthat (>= 3.0.0), rmarkdown, knitr
URL: https://github.com/termehs/netropy
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-24 08:32:36 UTC; termehshafie
Author: Termeh Shafie [aut, cre]
Maintainer: Termeh Shafie <termeh.shafie@uni-konstanz.de>
Repository: CRAN
Date/Publication: 2026-04-24 08:50:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:47:39 UTC; unix
